<?php

return [
    'number.decimals_separator' => '.',
    'number.thousands_separator' => ',',
    'None' => '없음',
    'Edit' => '수정',
    'Remove' => '삭제',
    'Yes' => '예',
    'No' => '아니오',
    'cancel' => '취소',
    'or' => '또는',
    'Yellow' => '노랑',
    'Blue' => '파랑',
    'Green' => '초록',
    'Purple' => '보라',
    'Red' => '빨강',
    'Orange' => '주황',
    'Grey' => '회색',
    'Brown' => '브라운',
    'Deep Orange' => '진홍',
    'Dark Grey' => '암회',
    'Pink' => '핑크',
    'Teal' => '암녹',
    'Cyan' => '청녹',
    'Lime' => '라임',
    'Light Green' => '연회',
    'Amber' => '호박',
    'Save' => '저장',
    'Login' => '로그인',
    'Official website:' => '공식 웹사이트:',
    'Unassigned' => '담당자 없음',
    'View this task' => '이 할일 보기',
    'Remove user' => '사용자 삭제',
    'Do you really want to remove this user: "%s"?' => '사용자 "%s"를 정말로 삭제하시겠습니까?',
    'All users' => '모든 사용자',
    'Username' => '사용자 이름',
    'Password' => '패스워드',
    'Administrator' => '관리자',
    'Sign in' => '로그인',
    'Users' => '사용자',
    'Forbidden' => '접근 거부',
    'Access Forbidden' => '접속이 거부되었습니다',
    'Edit user' => '사용자를 변경하는 ',
    'Logout' => '로그아웃',
    'Bad username or password' => '사용자 이름 또는 패스워드가 다릅니다.',
    'Edit project' => '프로젝트 수정',
    'Name' => '이름',
    'Projects' => '프로젝트',
    'No project' => '프로젝트가 없습니다',
    'Project' => '프로젝트',
    'Status' => '상태',
    'Tasks' => '할일',
    'Board' => '보드',
    'Actions' => 'Actions',
    'Inactive' => '무효',
    'Active' => '유효',
    'Unable to update this board.' => '보드를 갱신할 수 없었습니다',
    'Disable' => '비활성화',
    'Enable' => '유효하게 한다',
    'New project' => '새 프로젝트',
    'Do you really want to remove this project: "%s"?' => '프로젝트를 삭제하시겠습니까: "%s"?',
    'Remove project' => '프로젝트의 삭제',
    'Edit the board for "%s"' => '"%s"를 위한 보드 수정',
    'Add a new column' => '컬럼의 추가',
    'Title' => '제목',
    'Assigned to %s' => '담당자 %s',
    'Remove a column' => '컬럼 삭제',
    'Unable to remove this column.' => '(※)컬럼을 삭제할 수 없었습니다.',
    'Do you really want to remove this column: "%s"?' => '컬럼을 삭제하시겠습니까: "%s"?',
    'Settings' => '설정',
    'Application settings' => '애플리케이션의 설정',
    'Language' => '언어',
    'Webhook token:' => 'Webhook토큰:',
    'API token:' => 'API토큰:',
    'Database size:' => '데이터베이스의 사이즈:',
    'Download the database' => '데이터베이스의 다운로드',
    'Optimize the database' => '데이터베이스 최적화',
    '(VACUUM command)' => '(VACUUM명령)',
    '(Gzip compressed Sqlite file)' => '(GZip명령으로 압축된 Sqlite파일)',
    'Close a task' => '할일 마치기',
    'Column' => '컬럼',
    'Color' => '색',
    'Assignee' => '담당자',
    'Create another task' => '다른 할일 추가',
    'New task' => '새로운 할일',
    'Open a task' => '할일 열기',
    'Do you really want to open this task: "%s"?' => '할일은 시작 하시겠습니까: "%s"?',
    'Back to the board' => '보드로 돌아가기',
    'There is nobody assigned' => '담당자가 없습니다',
    'Column on the board:' => '컬럼:',
    'Close this task' => '할일 마치기',
    'Open this task' => '할일을 열다',
    'There is no description.' => '설명이 없다',
    'Add a new task' => '할일을 추가하는 ',
    'The username is required' => '사용자 이름이 필요합니다',
    'The maximum length is %d characters' => '최대 길이는 "%d" 글자 입니다',
    'The minimum length is %d characters' => '최소 길이는 "%d" 글자 입니다',
    'The password is required' => '패스워드가 필요합니다',
    'This value must be an integer' => '정수로 입력하세요',
    'The username must be unique' => '사용자 이름이 이미 사용되고 있습니다',
    'The user id is required' => '사용자 ID가 필요합니다',
    'Passwords don\'t match' => '패스워드가 일치하지 않습니다',
    'The confirmation is required' => '확인용 패스워드를 입력하세요',
    'The project is required' => '프로젝트가 필요합니다',
    'The id is required' => 'ID가 필요합니다',
    'The project id is required' => '프로젝트 ID가 필요합니다',
    'The project name is required' => '프로젝트 이름이 필요합니다',
    'The title is required' => '제목이 필요합니다',
    'Settings saved successfully.' => '설정을 저장하였습니다',
    'Unable to save your settings.' => '설정의 보존에 실패했습니다.',
    'Database optimization done.' => '데이터베이스 최적화가 끝났습니다.',
    'Your project has been created successfully.' => '프로젝트를 작성했습니다.',
    'Unable to create your project.' => '프로젝트의 작성에 실패했습니다.',
    'Project updated successfully.' => '프로젝트를 갱신했습니다.',
    'Unable to update this project.' => '프로젝트의 갱신에 실패했습니다.',
    'Unable to remove this project.' => '프로젝트의 삭제에 실패했습니다.',
    'Project removed successfully.' => '프로젝트를 삭제했습니다.',
    'Project activated successfully.' => '프로젝트를 유효로 했습니다.',
    'Unable to activate this project.' => '프로젝트의 유효하게 못했어요.',
    'Project disabled successfully.' => '프로젝트를 무효로 했습니다.',
    'Unable to disable this project.' => '프로젝트의 무효화할 수 없었습니다.',
    'Unable to open this task.' => '할일의 오픈에 실패했습니다.',
    'Task opened successfully.' => '할일을 오픈했습니다.',
    'Unable to close this task.' => '할일의 클로즈에 실패했습니다.',
    'Task closed successfully.' => '할일을 마쳤습니다.',
    'Unable to update your task.' => '할일의 갱신에 실패했습니다.',
    'Task updated successfully.' => '할일을 갱신했습니다.',
    'Unable to create your task.' => '할일의 추가에 실패했습니다.',
    'Task created successfully.' => '할일을 추가했습니다.',
    'User created successfully.' => '사용자를 추가했습니다.',
    'Unable to create your user.' => '사용자의 추가에 실패했습니다.',
    'User updated successfully.' => '사용자를 갱신했습니다.',
    'User removed successfully.' => '사용자를 삭제했습니다.',
    'Unable to remove this user.' => '사용자 삭제에 실패했습니다.',
    'Board updated successfully.' => '보드를 갱신했습니다.',
    'Ready' => '준비중',
    'Backlog' => '요구사항',
    'Work in progress' => '진행중',
    'Done' => '완료',
    'Application version:' => '애플리케이션의 버전:',
    'Id' => 'ID',
    'Public link' => '공개 접속 링크',
    'Timezone' => '시간대',
    'Sorry, I didn\'t find this information in my database!' => '데이터베이스에서 정보가 발견되지 않았습니다!',
    'Page not found' => '페이지가 발견되지 않는다',
    'Complexity' => '복잡도',
    'Task limit' => '할일 수 제한',
    'Task count' => '할일 수',
    'User' => '사용자',
    'Comments' => '댓글',
    'Comment is required' => '댓글을 입력하세요',
    'Comment added successfully.' => '의견을 추가했습니다.',
    'Unable to create your comment.' => '댓글의 추가에 실패했습니다.',
    'Due Date' => '마감일',
    'Invalid date' => '날짜가 무효입니다',
    'Automatic actions' => '자동액션 관리',
    'Your automatic action has been created successfully.' => '자동 액션을 작성했습니다.',
    'Unable to create your automatic action.' => '자동 액션의 작성에 실패했습니다.',
    'Remove an action' => '자동 액션의 삭제',
    'Unable to remove this action.' => '자동 액션의 삭제에 실패했습니다.',
    'Action removed successfully.' => '자동 액션의 삭제에 성공했어요.',
    'Automatic actions for the project "%s"' => '"%s" 프로젝트를 위한 자동 액션',
    'Add an action' => '자동 액션 추가',
    'Event name' => '이벤트 이름',
    'Action' => '액션',
    'Event' => '이벤트',
    'When the selected event occurs execute the corresponding action.' => '선택된 이벤트가 발생했을 때 대응하는 액션을 실행한다.',
    'Next step' => '다음 단계',
    'Define action parameters' => '액션의 바로미터',
    'Do you really want to remove this action: "%s"?' => '액션을 삭제하시겠습니까: "%s"?',
    'Remove an automatic action' => '자동 액션의 삭제',
    'Assign the task to a specific user' => '할일 담당자를 할당',
    'Assign the task to the person who does the action' => '액션을 일으킨 사용자를 담당자이자',
    'Duplicate the task to another project' => ' 다른 프로젝트에 할일을 복제하는 ',
    'Move a task to another column' => '할일을 다른 컬럼에 이동하는 ',
    'Task modification' => '할일 변경',
    'Task creation' => '할일을 만들',
    'Closing a task' => '할일을 닫혔다',
    'Assign a color to a specific user' => '색을 사용자에 할당',
    'Position' => '위치',
    'Duplicate to project' => '다른 프로젝트에 복사',
    'Duplicate' => '복사',
    'Link' => '링크',
    'Comment updated successfully.' => '댓글을 갱신했습니다.',
    'Unable to update your comment.' => '댓글의 갱신에 실패했습니다.',
    'Remove a comment' => '댓글 삭제',
    'Comment removed successfully.' => '댓글을 삭제했습니다.',
    'Unable to remove this comment.' => '댓글의 삭제에 실패했습니다.',
    'Do you really want to remove this comment?' => '댓글을 삭제합니까?',
    'Current password for the user "%s"' => '사용자 "%s"의 현재 패스워드',
    'The current password is required' => '현재의 패스워드를 입력하세요',
    'Wrong password' => '패스워드가 다릅니다',
    'Unknown' => '불명',
    'Last logins' => '마지막 로그인',
    'Login date' => '로그인 일시',
    'Authentication method' => '인증 방법',
    'IP address' => 'IP 주소',
    'User agent' => '사용자 에이전트',
    'Persistent connections' => '세션',
    'No session.' => '세션 없음',
    'Expiration date' => '유효기간',
    'Remember Me' => '자동 로그인',
    'Creation date' => '작성일',
    'Everybody' => '모두',
    'Open' => '열림',
    'Closed' => '닫힘',
    'Search' => '검색',
    'Nothing found.' => '결과가 없습니다',
    'Due date' => '마감일',
    'Description' => '설명',
    '%d comments' => '%d개의 댓글',
    '%d comment' => '%d개의 댓글',
    'Email address invalid' => '메일 주소가 올바르지 않습니다.',
    'Your external account is not linked anymore to your profile.' => '외부 계정과 프로필이 더이상 연결되지 않습니다',
    'Unable to unlink your external account.' => '외부 계정과 연결 해제에 실패하였습니다',
    'External authentication failed' => '외부 인증 실패',
    'Your external account is linked to your profile successfully.' => '외부 계정과 프로필이 성공적으로 연결되었습니다',
    'Email' => '이메일',
    'Task removed successfully.' => '할일을 삭제했습니다.',
    'Unable to remove this task.' => '할일 삭제에 실패하였습니다',
    'Remove a task' => '할일 삭제',
    'Do you really want to remove this task: "%s"?' => '할일을 삭제하시겠습니까: "%s"?',
    'Assign automatically a color based on a category' => '카테고리에 바탕을 두고 색을 바꾸고',
    'Assign automatically a category based on a color' => '색에 바탕을 두고 카테고리를 바꾸었다',
    'Task creation or modification' => '할일의 작성 또는 변경',
    'Category' => '카테고리',
    'Category:' => '카테고리:',
    'Categories' => '카테고리',
    'Your category has been created successfully.' => '카테고리를 작성했습니다.',
    'This category has been updated successfully.' => '카테고리를 갱신했습니다.',
    'Unable to update this category.' => '카테고리의 갱신에 실패했습니다.',
    'Remove a category' => '카테고리의 삭제',
    'Category removed successfully.' => '카테고리를 삭제했습니다.',
    'Unable to remove this category.' => '카테고리를 삭제할 수 없었습니다.',
    'Category modification for the project "%s"' => '"%s" 프로젝트 카테고리 수정',
    'Category Name' => '카테고리 이름',
    'Add a new category' => '카테고리의 추가',
    'Do you really want to remove this category: "%s"?' => '카테고리를 삭제하시겠습니까: "%s"?',
    'All categories' => '모든 카테고리',
    'No category' => '카테고리 없음',
    'The name is required' => '이름을 입력하십시오',
    'Remove a file' => '파일 삭제',
    'Unable to remove this file.' => '파일 삭제에 실패했습니다.',
    'File removed successfully.' => '파일을 삭제했습니다.',
    'Attach a document' => '문서 첨부',
    'Do you really want to remove this file: "%s"?' => '파일 "%s" 을 삭제할까요?',
    'Attachments' => '첨부',
    'Edit the task' => '할일 수정',
    'Add a comment' => '댓글 추가',
    'Edit a comment' => '댓글 수정',
    'Summary' => '개요',
    'Time tracking' => '시간 추적',
    'Estimate:' => '예측:',
    'Spent:' => '경과:',
    'Do you really want to remove this sub-task?' => '서브 할일을 삭제합니까?',
    'Remaining:' => '나머지:',
    'hours' => '시간',
    'estimated' => '예측',
    'Sub-Tasks' => '서브 할일',
    'Add a sub-task' => '서브 할일 추가',
    'Original estimate' => '최초 예측시간',
    'Create another sub-task' => '다음 서브 할일 추가',
    'Time spent' => '경과시간',
    'Edit a sub-task' => '서브 할일을 변경하는 ',
    'Remove a sub-task' => '서브 할일을 삭제하는 ',
    'The time must be a numeric value' => '시간은 숫자로 입력하세요',
    'Todo' => '할일 예정',
    'In progress' => '할일 중',
    'Sub-task removed successfully.' => '서브 할일을 삭제했습니다.',
    'Unable to remove this sub-task.' => '서브 할일의 삭제가 실패했습니다.',
    'Sub-task updated successfully.' => '서브 할일을 갱신했습니다.',
    'Unable to update your sub-task.' => '서브 할일의 경신에 실패했습니다.',
    'Unable to create your sub-task.' => '서브 할일의 추가에 실패했습니다.',
    'Maximum size: ' => '최대: ',
    'Display another project' => '프로젝트 보기',
    'Created by %s' => '작성자 %s',
    'Tasks Export' => '할일 내보내기',
    'Start Date' => '시작일',
    'Execute' => '실행',
    'Task Id' => '할일 ID',
    'Creator' => '작성자',
    'Modification date' => '변경 일',
    'Completion date' => '완료일',
    'Clone' => '복사',
    'Project cloned successfully.' => '프로젝트를 복제했습니다.',
    'Unable to clone this project.' => '프로젝트의 복제에 실패했습니다.',
    'Enable email notifications' => '이메일 알림 설정',
    'Task position:' => '할일 위치:',
    'The task #%d has been opened.' => '할일 #%d가 시작되었습니다',
    'The task #%d has been closed.' => '할일 #%d가 종료되었습니다',
    'Sub-task updated' => '서브 할일 갱신',
    'Title:' => '제목:',
    'Status:' => '상태:',
    'Assignee:' => '담당:',
    'Time tracking:' => '시간 계측:',
    'New sub-task' => '새로운 서브 할일',
    'New attachment added "%s"' => '"%s"의 새로운 첨부 파일',
    'New comment posted by %s' => '"%s"님이 댓글을 추가하였습니다',
    'New comment' => ' 새로운 댓글',
    'Comment updated' => '댓글가 갱신되었습니다',
    'New subtask' => ' 새로운 서브 할일',
    'I only want to receive notifications for these projects:' => '다음 프로젝트의 알림만 받겠습니다:',
    'view the task on Kanboard' => 'Kanboard에서 할일을 본다',
    'Public access' => '공개 접속 설정',
    'Disable public access' => '공개 접속 비활성화',
    'Enable public access' => '공개 접속 활성화',
    'Public access disabled' => '공개 접속 불가',
    'Move the task to another project' => '할일별 프로젝트에 옮기',
    'Move to project' => '다른 프로젝트로 이동',
    'Do you really want to duplicate this task?' => '할일을 복제합니까?',
    'Duplicate a task' => '할일 복사',
    'External accounts' => '외부 계정',
    'Account type' => '계정종류',
    'Local' => '로컬',
    'Remote' => '원격',
    'Enabled' => '활성화',
    'Disabled' => '비활성화',
    'Login:' => '사용자명',
    'Full Name:' => '이름:',
    'Email:' => '이메일:',
    'Notifications:' => '알림:',
    'Notifications' => '알림',
    'Account type:' => '계정종류:',
    'Edit profile' => '프로필 변경',
    'Change password' => '패스워드 변경',
    'Password modification' => '패스워드 변경',
    'External authentications' => '외부 인증',
    'Never connected.' => '접속기록없음',
    'No external authentication enabled.' => '외부 인증이 설정되어 있지 않습니다.',
    'Password modified successfully.' => '패스워드를 변경했습니다.',
    'Unable to change the password.' => '비밀 번호가 변경할 수 없었습니다.',
    'Change category' => '카테고리 수정',
    '%s updated the task %s' => '%s이 할일 %s을 갱신 하였습니다',
    '%s opened the task %s' => '%s이 할일 %s을 시작시켰습니다',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s이 할일%s을 위치#%d컬럼%s로 옮겼습니다',
    '%s moved the task %s to the column "%s"' => '%s이 할일 %s을 컬럼 "%s" 로 옮겼습니다',
    '%s created the task %s' => '%s이 할일%s을 추가했습니다',
    '%s closed the task %s' => '%s이 할일%s을 마쳤습니다',
    '%s created a subtask for the task %s' => '%s이 할일%s의 서브 할일을 추가했습니다',
    '%s updated a subtask for the task %s' => '%s이 할일%s의 서브 할일을 갱신했습니다',
    'Assigned to %s with an estimate of %s/%sh' => '담당자 %s에게 예상 %s/%sh을 할당했습니다',
    'Not assigned, estimate of %sh' => '예상 %sh가 할당되지 않았습니다',
    '%s updated a comment on the task %s' => '%s이 할일%s의 댓글을 수정했습니다',
    '%s commented the task %s' => '%s이 할일%s에 댓글을 남겼습니다',
    '%s\'s activity' => '%s의 활동',
    'RSS feed' => 'RSS피드',
    '%s updated a comment on the task #%d' => '%s이 할일#%d의 댓글을 수정했습니다',
    '%s commented on the task #%d' => '%s이 할일#%d을 언급하였습니다',
    '%s updated a subtask for the task #%d' => '%s이 할일#%d의 서브 할일을 수정했습니다',
    '%s created a subtask for the task #%d' => '%s이 할일#%d의 서브 할일을 수정했습니다',
    '%s updated the task #%d' => '%s이 할일#%d을 갱신했습니다',
    '%s created the task #%d' => '%s이 할일#%d을 추가했습니다',
    '%s closed the task #%d' => '%s이 할일#%d을 닫혔습니다',
    '%s opened the task #%d' => '%s이 할일#%d를 오픈했습니다',
    'Activity' => '활동',
    'Default values are "%s"' => '기본 값은 "%s" 입니다',
    'Default columns for new projects (Comma-separated)' => '새로운 프로젝트의 기본 컬럼 (콤마(,)로 분리됨)',
    'Task assignee change' => '담당자의 변경',
    '%s changed the assignee of the task #%d to %s' => '%s이 할일 #%d의 담당을 %s로 변경합니다',
    '%s changed the assignee of the task %s to %s' => '%s이 할일 %s의 담당을 %s로 변경했습니다',
    'New password for the user "%s"' => '사용자 "%s"의 새로운 패스워드',
    'Choose an event' => '행사의 선택',
    'Create a task from an external provider' => '할일을 외부 서비스로부터 작성하는 ',
    'Change the assignee based on an external username' => '담당자를 외부 서비스에 바탕을 두고 변경하는 ',
    'Change the category based on an external label' => '카테고리를 외부 서비스에 바탕을 두고 변경하는 ',
    'Reference' => '참조',
    'Label' => '라벨',
    'Database' => '데이터베이스',
    'About' => '정보',
    'Database driver:' => '데이터베이스 드라이버:',
    'Board settings' => '기본 설정',
    'Webhook settings' => 'Webhook의 설정',
    'Reset token' => '토큰 리셋',
    'API endpoint:' => 'API엔드 포인트:',
    'Refresh interval for personal board' => '비공개 보드의 갱신 빈도',
    'Refresh interval for public board' => '공개 보드의 갱신 빈도',
    'Task highlight period' => '할일의 하이라이트 기간',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => '최근 수정된 작업 고려 기간(초), (비활성화:0, 기본값:2일)',
    'Frequency in second (60 seconds by default)' => '초당 횟수(기본값:60초)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => '초당 횟수(비활성화:0, 기본값:10초)',
    'Application URL' => '애플리케이션의 URL',
    'Token regenerated.' => '토큰이 다시 생성되었습니다.',
    'Date format' => '데이터 포멧',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO 포멧은 항상 가능합니다. 예를 들어: "%s" 와 "%s"',
    'New personal project' => '새 비공개 프로젝트',
    'This project is personal' => '이 프로젝트는 비공개입니다',
    'Add' => '추가',
    'Start date' => '시작시간',
    'Time estimated' => '예상시간',
    'There is nothing assigned to you.' => '할일이 없습니다. 옆사람의 일을 도와주면 어떨까요?',
    'My tasks' => '내 할일',
    'Activity stream' => '활동기록',
    'Dashboard' => '대시보드',
    'Confirmation' => '확인',
    'Webhooks' => 'Webhook',
    'API' => 'API',
    'Create a comment from an external provider' => '외부 서비스로부터 의견을 작성한다',
    'Project management' => '프로젝트 관리',
    'Columns' => '컬럼',
    'Task' => '할일',
    'Percentage' => '비중',
    'Number of tasks' => '할일 수',
    'Task distribution' => '할일 분포',
    'Analytics' => '분석',
    'Subtask' => '서브 할일',
    'User repartition' => '담당자 분포',
    'Clone this project' => '이 프로젝트를 복제하는 ',
    'Column removed successfully.' => '(※)컬럼을 삭제했습니다',
    'Not enough data to show the graph.' => '그래프를 선묘화하려면 나왔지만 부족합니다',
    'Previous' => ' 돌아가',
    'The id must be an integer' => 'id은 숫자가 아니면 안 됩니다',
    'The project id must be an integer' => 'project id은 숫자가 아니면 안 됩니다',
    'The status must be an integer' => 'status는 숫자지 않으면 안 됩니다',
    'The subtask id is required' => 'subtask id가 필요합니다',
    'The subtask id must be an integer' => 'subtask id은 숫자가 아니면 안 됩니다',
    'The task id is required' => 'task id가 필요합니다',
    'The task id must be an integer' => 'task id은 숫자가 아니면 안 됩니다',
    'The user id must be an integer' => 'user id은 숫자가 아니면 안 됩니다',
    'This value is required' => '이 값이 필요합니다',
    'This value must be numeric' => '이 값은 숫자가 아니면 안 됩니다',
    'Unable to create this task.' => '이 할일을 작성할 수 없었습니다',
    'Cumulative flow diagram' => '축적 흐름',
    'Daily project summary' => '하루 프로젝트 개요',
    'Daily project summary export' => '하루 프로젝트 개요의 출력',
    'Exports' => '출력',
    'This export contains the number of tasks per column grouped per day.' => '이 출력은 날짜의 칼람별 할일 수를 집계한 것입니다',
    'Active swimlanes' => '액티브한 스윔레인',
    'Add a new swimlane' => ' 새로운 스윔레인',
    'Default swimlane' => '기본 스윔레인',
    'Do you really want to remove this swimlane: "%s"?' => '스웜레인을 삭제하시겠습니까: "%s"?',
    'Inactive swimlanes' => '인터랙티브한 스윔레인',
    'Remove a swimlane' => '스윔레인의 삭제',
    'Swimlane modification for the project "%s"' => '"%s" 프로젝트의 스웜레인 수정',
    'Swimlane removed successfully.' => '스윔레인을 삭제했습니다.',
    'Swimlanes' => '스윔레인',
    'Swimlane updated successfully.' => '스윔레인을 갱신했습니다.',
    'Unable to remove this swimlane.' => '스윔레인을 삭제할 수 없었습니다.',
    'Unable to update this swimlane.' => '스윔레인을 갱신할 수 없었습니다.',
    'Your swimlane has been created successfully.' => '스윔레인이 작성되었습니다.',
    'Example: "Bug, Feature Request, Improvement"' => '예: "버그, 특성 요청, 향상"',
    'Default categories for new projects (Comma-separated)' => '새로운 프로젝트의 기본 카테고리 (콤마(,)로 구분)',
    'Integrations' => '연계',
    'Integration with third-party services' => '외부 서비스 연계',
    'Subtask Id' => '서브 할일 Id',
    'Subtasks' => '서브 할일',
    'Subtasks Export' => '서브 할일 출력',
    'Task Title' => '할일 제목',
    'Untitled' => '제목 없음',
    'Application default' => '애플리케이션 기본',
    'Language:' => '언어:',
    'Timezone:' => '시간대:',
    'All columns' => '모든 컬럼',
    'Next' => '다음에 ',
    '#%d' => '#%d',
    'All swimlanes' => '모든 스윔레인',
    'All colors' => '모든 색',
    'Moved to column %s' => '"%s" 컬럼으로 이동',
    'User dashboard' => '대시보드',
    'Allow only one subtask in progress at the same time for a user' => '한 사용자에 대한 하나의 할일만 진행 중에 가능합니다',
    'Edit column "%s"' => '"%s" 컬럼 수정',
    'Select the new status of the subtask: "%s"' => '서브 할일의 새로운 상태 선택: "%s"',
    'Subtask timesheet' => '서브 할일 타임시트',
    'There is nothing to show.' => '기록이 없습니다',
    'Time Tracking' => '시간 트레킹',
    'You already have one subtask in progress' => '이미 진행 중인 서브 할일가 있습니다.',
    'Which parts of the project do you want to duplicate?' => '프로젝트의 무엇을 복제합니까?',
    'Disallow login form' => '허가되지 않은 로그인 양식',
    'Start' => '시작',
    'End' => '종료',
    'Task age in days' => '할일이 생긴 시간',
    'Days in this column' => '이 컬럼에 있는 시간',
    '%dd' => '%d일',
    'Add a new link' => ' 새로운 링크 추가',
    'Do you really want to remove this link: "%s"?' => '링크를 삭제하시겠습니까: "%s"?',
    'Do you really want to remove this link with task #%d?' => '#%d 할일의 링크를 삭제하시겠습니까?',
    'Field required' => '필드가 필요합니다',
    'Link added successfully.' => '링크를 추가했습니다.',
    'Link updated successfully.' => '링크를 갱신했습니다.',
    'Link removed successfully.' => '링크를 삭제했습니다.',
    'Link labels' => '링크 라벨',
    'Link modification' => '링크의 변경',
    'Opposite label' => '반대의 라벨',
    'Remove a link' => '라벨의 삭제',
    'The labels must be different' => ' 다른 라벨을 지정하세요',
    'There is no link.' => '링크가 없습니다',
    'This label must be unique' => '라벨은 독특할 필요가 있습니다',
    'Unable to create your link.' => '링크를 작성할 수 없었습니다.',
    'Unable to update your link.' => '링크를 갱신할 수 없었습니다.',
    'Unable to remove this link.' => '링크를 삭제할 수 없었습니다.',
    'relates to' => '연관 링크',
    'blocks' => '다음을 딜레이하는',
    'is blocked by' => '다음 때문에 딜레이되는',
    'duplicates' => '다음과 중복하는',
    'is duplicated by' => '다음에 중복되는',
    'is a child of' => '다음의 하위 할일',
    'is a parent of' => '다음의 상위 할일',
    'targets milestone' => '다음의 이정표를 목표로 하는',
    'is a milestone of' => '다음의 이정표인',
    'fixes' => '다음을 수정하는',
    'is fixed by' => '다음에 의해 수정되는',
    'This task' => '이 할일의 ',
    '<1h' => '<1시간',
    '%dh' => '%d시간',
    'Expand tasks' => '할일 크게',
    'Collapse tasks' => '할일 작게',
    'Expand/collapse tasks' => '할일 크게/작게',
    'Close dialog box' => '다이얼로그를 닫습니다',
    'Submit a form' => '제출',
    'Board view' => '보드 뷰',
    'Keyboard shortcuts' => '키보드 숏 컷',
    'Open board switcher' => '보드 전환을 열',
    'Application' => '애플리케이션',
    'Compact view' => '컴팩트 뷰',
    'Horizontal scrolling' => '세로 스크롤',
    'Compact/wide view' => '컴팩트/와이드 뷰',
    'Currency' => '통화',
    'Personal project' => '개인 프로젝트',
    'AUD - Australian Dollar' => 'AUD - 호주 달러',
    'CAD - Canadian Dollar' => 'CAD -캐나다 달러',
    'CHF - Swiss Francs' => 'CHF - 스위스 프랑',
    'Custom Stylesheet' => '커스텀 스타일 시트',
    'EUR - Euro' => 'EUR - 유로',
    'GBP - British Pound' => 'GBP - 영국 파운드',
    'INR - Indian Rupee' => 'INR - 인도 루피',
    'JPY - Japanese Yen' => 'JPY - 일본 엔',
    'NZD - New Zealand Dollar' => 'NZD - 뉴질랜드 달러',
    'PEN - Peruvian Sol' => 'PEN - 페루 솔',
    'RSD - Serbian dinar' => 'RSD - 세르비아 디나르',
    'CNY - Chinese Yuan' => 'CNY - 중국 위안',
    'USD - US Dollar' => 'USD - 미국 달러',
    'VES - Venezuelan Bolívar' => 'VES - 베네수엘라 볼리바르',
    'Destination column' => '이동 후 컬럼',
    'Move the task to another column when assigned to a user' => '사용자의 할당을 하면 할일을 다른 컬럼에 이동',
    'Move the task to another column when assignee is cleared' => '사용자의 할당이 없어지면 할일을 다른 컬럼에 이동',
    'Source column' => '이동 전 컬럼',
    'Transitions' => '이력',
    'Executer' => '실행자',
    'Time spent in the column' => '컬럼에 있던 시간',
    'Task transitions' => '할일 천이',
    'Task transitions export' => '할일 천이를 출력',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => '이 리포트는 할일의 컬럼 간 이동을 시간, 유저, 경과 시간과 함께 기록한 것입니다.',
    'Currency rates' => '환율',
    'Rate' => '레이트',
    'Change reference currency' => '현재의 기축 통화',
    'Reference currency' => '기축 통화',
    'The currency rate has been added successfully.' => '통화가 성공적으로 추가되었습니다',
    'Unable to add this currency rate.' => '이 통화 환율을 추가할 수 없습니다.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s이 할일 %s의 담당을 삭제했습니다',
    'Information' => '정보',
    'Check two factor authentication code' => '2단 인증을 체크한다',
    'The two factor authentication code is not valid.' => '2단 인증 코드는 무효입니다.',
    'The two factor authentication code is valid.' => '2단 인증 코드는 유효합니다.',
    'Code' => '코드',
    'Two factor authentication' => '2단 인증',
    'This QR code contains the key URI: ' => 'QR 코드는 키 URI를 포함합니다: ',
    'Check my code' => '코드 체크',
    'Secret key: ' => '비밀키: ',
    'Test your device' => '디바이스 테스트',
    'Assign a color when the task is moved to a specific column' => '상세 컬럼으로 이동할 할일의 색깔을 지정하세요',
    '%s via Kanboard' => '%s via E-board',
    'Burndown chart' => '번다운 차트',
    'This chart show the task complexity over the time (Work Remaining).' => '이 차트는 시간에 따른 할일의 복잡성을 보여줍니다. (남아있는 일)',
    'Screenshot taken %s' => '스크린샷_%s',
    'Add a screenshot' => '스크린샷 추가',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => '스크린샷을 CTRL+V 혹은 ⌘+V를 눌러 붙여넣기',
    'Screenshot uploaded successfully.' => '스크린샷을 업로드하였습니다',
    'SEK - Swedish Krona' => 'SEK - 스위스 크로나',
    'Identifier' => '식별자',
    'Disable two factor authentication' => '이중 인증 비활성화',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => '"%s" 담당자의 이중 인증을 비활성화 하시겠습니까?',
    'Edit link' => '링크 수정',
    'Start to type task title...' => '할일 제목을 입력하세요',
    'A task cannot be linked to itself' => '할일을 자기자신에게 연결할 수 없습니다',
    'The exact same link already exists' => '동일한 링크가 이미 존재합니다',
    'Recurrent task is scheduled to be generated' => '반복 할일이 생성된 예정입니다.',
    'Score' => '점수',
    'The identifier must be unique' => '식별자는 유일해야 합니다',
    'This linked task id doesn\'t exists' => '연결된 할일 ID가 존재하지 않습니다',
    'This value must be alphanumeric' => '글자와 숫자만 가능합니다',
    'Edit recurrence' => '반복 수정',
    'Generate recurrent task' => '반복 할일 생성',
    'Trigger to generate recurrent task' => '반복 할일 생성 트리거',
    'Factor to calculate new due date' => '새로운 종료날짜 계산',
    'Timeframe to calculate new due date' => '종료날짜 계산 단위',
    'Base date to calculate new due date' => '새로운 기본 종료날짜 계산',
    'Action date' => '시작날짜',
    'Base date to calculate new due date: ' => '새로운 기본 종료날짜 계산: ',
    'This task has created this child task: ' => '이 할일은 하위 할일을 만들었습니다.',
    'Day(s)' => '일',
    'Existing due date' => '기존 종료날짜',
    'Factor to calculate new due date: ' => '새로운 종료날짜 계산: ',
    'Month(s)' => '월',
    'This task has been created by: ' => '할일을 만들었습니다: ',
    'Recurrent task has been generated:' => '반복 할일이 생성되었습니다',
    'Timeframe to calculate new due date: ' => '종료날짜 계산 단위',
    'Trigger to generate recurrent task: ' => '반복 할일 생성 트리거',
    'When task is closed' => '할일을 마쳤을때',
    'When task is moved from first column' => '할일이 첫번째 컬럼으로 옮겨졌을때',
    'When task is moved to last column' => '할일이 마지막 컬럼으로 옮겨졌을때',
    'Year(s)' => '년',
    'Project settings' => '프로젝트 설정',
    'Automatically update the start date' => '시작일에 자동 갱신',
    'iCal feed' => 'iCal 피드',
    'Preferences' => '우선권',
    'Security' => '보안',
    'Two factor authentication disabled' => '이중 인증이 비활성화 되었습니다',
    'Two factor authentication enabled' => '이중 인증이 활성화 되었습니다',
    'Unable to update this user.' => '담당자 갱신이 가능합니다',
    'There is no user management for personal projects.' => '비밀 프로젝트의 관리 담당자가 없습니다',
    'User that will receive the email' => '그 담당자가 이메일을 수신할 것입니다',
    'Email subject' => '이메일 제목',
    'Date' => '날짜',
    'Add a comment log when moving the task between columns' => '컬럼 중간의 할일이 이동할 때 의견 달기',
    'Move the task to another column when the category is changed' => '카테고리 변경시 할일을 다른 컬럼으로 이동',
    'Send a task by email to someone' => '할일을 이메일로 보내기',
    'Reopen a task' => '할일 다시 시작',
    'Notification' => '알림',
    '%s moved the task #%d to the first swimlane' => '%s가 할일 #%d를 첫번째 스웜레인으로 이동시켰습니다',
    'Swimlane' => '스윔레인',
    '%s moved the task %s to the first swimlane' => '%s가 할일 %s를 첫번째 스웜레인으로 이동시켰습니다',
    '%s moved the task %s to the swimlane "%s"' => '%s가 할일 %s를 %s 스웜레인으로 이동시켰습니다',
    'This report contains all subtasks information for the given date range.' => '해당 기간의 모든 서브 할일 정보가 보고서에 포함됩니다',
    'This report contains all tasks information for the given date range.' => '해당 기간의 모든 할일 정보가 보고서에 포함됩니다',
    'Project activities for %s' => '%s의 프로젝트 활성화',
    'view the board on Kanboard' => 'kanboard로 보드 보기',
    'The task has been moved to the first swimlane' => '할일이 첫번째 스웜라인으로 이동되어 있습니다',
    'The task has been moved to another swimlane:' => '할일이 다른 스웜라인으로 이동되어 있습니다',
    'New title: %s' => '제목 변경: %s',
    'The task is not assigned anymore' => '담당자 없음',
    'New assignee: %s' => '담당자 변경: %s',
    'There is no category now' => '카테고리 없음',
    'New category: %s' => '카테고리 변경: %s',
    'New color: %s' => '색깔 변경: %s',
    'New complexity: %d' => '복잡도 변경: %d',
    'The due date has been removed' => '마감날짜 삭제',
    'There is no description anymore' => '설명 없음',
    'Recurrence settings has been modified' => '반복할일 설정 수정',
    'Time spent changed: %sh' => '경과시간 변경: %s시간',
    'Time estimated changed: %sh' => '%s시간으로 예상시간 변경',
    'The field "%s" has been updated' => '%s 필드가 갱신되어 있습니다',
    'The description has been modified:' => '설명이 수정되어 있습니다: ',
    'Do you really want to close the task "%s" as well as all subtasks?' => '할일 "%s"과 서브 할일을 모두 마치시겠습니까?',
    'I want to receive notifications for:' => '다음의 알림을 받기를 원합니다:',
    'All tasks' => '모든 할일',
    'Only for tasks assigned to me' => '내가 담당자인 일',
    'Only for tasks created by me' => '내가 만든 일',
    'Only for tasks created by me and tasks assigned to me' => '내가 만들었거나 내가 담당자인 일',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => '모든 컬럼',
    'You need at least 2 days of data to show the chart.' => '차트를 보기 위하여 최소 2일의 데이터가 필요합니다',
    '<15m' => '<15분',
    '<30m' => '<30분',
    'Stop timer' => '타이머 정지',
    'Start timer' => '타이머 시작',
    'My activity stream' => '내 활동기록',
    'Search tasks' => '할일 찾기',
    'Reset filters' => '필터 리셋',
    'My tasks due tomorrow' => '내일까지 내 할일',
    'Tasks due today' => '오늘까지 할일',
    'Tasks due tomorrow' => '내일까지 할일',
    'Tasks due yesterday' => '어제까지 할일',
    'Closed tasks' => '닫힌 할일',
    'Open tasks' => '열린 할일',
    'Not assigned' => '담당자가 없는 일',
    'View advanced search syntax' => '추가 검색 문법보기',
    'Overview' => '개요',
    'Board/Calendar/List view' => '보드/달력/리스트 보기',
    'Switch to the board view' => '보드 보기로 전환',
    'Switch to the list view' => '리스트 보기로 전환',
    'Go to the search/filter box' => '검색/필터 박스로 이동',
    'There is no activity yet.' => '활동이 없습니다',
    'No tasks found.' => '할일을 찾을 수 없습니다',
    'Keyboard shortcut: "%s"' => '쉬운 키보드: "%s"',
    'List' => '목록',
    'Filter' => '필터',
    'Advanced search' => '검색 문법',
    'Example of query: ' => '문법 예제 ',
    'Search by project: ' => '프로젝트로 찾기 ',
    'Search by column: ' => '컬럼으로 찾기 ',
    'Search by assignee: ' => '담당자로 찾기 ',
    'Search by color: ' => '색깔로 찾기 ',
    'Search by category: ' => '카테고리로 찾기 ',
    'Search by description: ' => '설명으로 찾기 ',
    'Search by due date: ' => '마감날짜로 찾기 ',
    'Average time spent in each column' => '각 칼럼의 평균 소요시간',
    'Average time spent' => '평균 소요시간',
    'This chart shows the average time spent in each column for the last %d tasks.' => '마지막 %d 할일의 컬럼 평균 소요시간을 차트에 표시합니다',
    'Average Lead and Cycle time' => '평균 Lead and Cycle 시간',
    'Average lead time: ' => '평균 lead 시간',
    'Average cycle time: ' => '평균 cycle 시간',
    'Cycle Time' => '사이클 시간',
    'Lead Time' => '리드 시간',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => '마지막 %d 할일의 평균 리드와 사이클 시간을 차트에 표시합니다',
    'Average time into each column' => '각 컬럼의 평균 시간',
    'Lead and cycle time' => '리드와 사이클 시간',
    'Lead time: ' => '리드 시간: ',
    'Cycle time: ' => '사이클 시간: ',
    'Time spent in each column' => '각 컬럼에서 걸린 시간',
    'The lead time is the duration between the task creation and the completion.' => '리드 시간은 할일의 생성부터 완료까지의 기간입니다',
    'The cycle time is the duration between the start date and the completion.' => '사이클 시간은 할일의 시작일부터 완료까지의 기간입니다',
    'If the task is not closed the current time is used instead of the completion date.' => '할일이 종료되지 않았다면, 완료 시간 대신 현재 시간이 사용됩니다',
    'Set the start date automatically' => '자동으로 시작 날짜를 설정합니다',
    'Edit Authentication' => '계정 수정',
    'Remote user' => '원격 담당자',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => '예를 들어 LDAP, Google, Github 계정같은 원격 담당자의 비밀번호는 칸반보드 데이터베이스에 저장하지 않습니다',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => '만약 "로그인 폼 거절"에 체크한다면, 로그인 폼에 접근할 자격이 무시됩니다',
    'Default task color' => '기본 할일 색',
    'This feature does not work with all browsers.' => '이 기능은 일부 브라우저에서 작동하지 않습니다',
    'There is no destination project available.' => '가능한 목적 프로젝트가 없습니다',
    'Trigger automatically subtask time tracking' => '자동 서브 할일 시간 트래킹 트리거',
    'Include closed tasks in the cumulative flow diagram' => '누적 플로우 다이어그램에 종료된 할일을 포함합니다',
    'Current swimlane: %s' => '현재 스웜라인: %s',
    'Current column: %s' => '현재 컬럼: %s',
    'Current category: %s' => '현재 카테고리: %s',
    'no category' => '카테고리 아님',
    'Current assignee: %s' => '현재 할당자: %s',
    'not assigned' => '할당되지 않음',
    'Author:' => '글쓴이:',
    'contributors' => '기여자',
    'License:' => '라이센스:',
    'License' => '라이센스',
    'Enter the text below' => '아랫글로 들어가기',
    'Start date:' => '시작일:',
    'Due date:' => '만기일:',
    'People who are project managers' => '프로젝트 매니저',
    'People who are project members' => '프로젝트 멤버',
    'NOK - Norwegian Krone' => 'NOK - 노르웨이 크로네',
    'Show this column' => '컬럼 보이기',
    'Hide this column' => '컬럼 숨기기',
    'End date' => '종료 날짜',
    'Users overview' => '유저 전체보기',
    'Members' => '멤버',
    'Shared project' => '프로젝트 공유',
    'Project managers' => '프로젝트 매니저',
    'Projects list' => '프로젝트 리스트',
    'End date:' => '날짜 수정',
    'Change task color when using a specific task link' => '특정 할일 링크를 사용할때 할일의 색깔 변경',
    'Task link creation or modification' => '할일 링크 생성 혹은 수정',
    'Milestone' => '마일스톤',
    'Reset the search/filter box' => '찾기/필터 박스 초기화',
    'Documentation' => '문서',
    'Author' => '글쓴이',
    'Version' => '버전',
    'Plugins' => '플러그인',
    'There is no plugin loaded.' => '플러그인이 로드되지 않았습니다',
    'My notifications' => '내 알림',
    'Custom filters' => '사용자 정의 필터',
    'Your custom filter has been created successfully.' => '사용자 정의 필터가 성공적으로 생성되었습니다',
    'Unable to create your custom filter.' => '사용자 정의 필터 생성 비활성화',
    'Custom filter removed successfully.' => '사용자 정의 필터가 성공적으로 삭제되었습니다',
    'Unable to remove this custom filter.' => '정의 필터 삭제 비활성화',
    'Edit custom filter' => '정의 필터 수정',
    'Your custom filter has been updated successfully.' => '사용자 정의 필터가 성공적으로 수정되었습니다',
    'Unable to update custom filter.' => '정의 필터 수정 비활성화',
    'Web' => '웹',
    'New attachment on task #%d: %s' => '할일 #%d의 새로운 첨부파일: %s',
    'New comment on task #%d' => '할일 #%d에 새로운 댓글이 달렸습니다',
    'Comment updated on task #%d' => '할일 #%d에 댓글이 갱신 되었습니다',
    'New subtask on task #%d' => '서브 할일 #%d이 갱신 되었습니다',
    'Subtask updated on task #%d' => '서브 할일 #%d가 갱신 되었습니다',
    'New task #%d: %s' => '할일 #%d: %s이 추가되었습니다',
    'Task updated #%d' => '할일 #%d이 갱신 되었습니다',
    'Task #%d closed' => '할일 #%d를 마쳤습니다',
    'Task #%d opened' => '할일 #%d가 시작되었습니다',
    'Column changed for task #%d' => '할일 #%d의 컬럼이 변경되었습니다',
    'New position for task #%d' => '할일 #%d이 새로운 위치에 등록되었습니다',
    'Swimlane changed for task #%d' => '#%d 할일의 스웜라인이 변경됩니다',
    'Assignee changed on task #%d' => '#%d 할일의 담당자가 변경됩니다',
    '%d overdue tasks' => '할일의 기한이 %d일 지났습니다',
    'No notification.' => '알림이 없습니다',
    'Mark all as read' => '모두 읽음',
    'Mark as read' => '읽음',
    'Total number of tasks in this column across all swimlanes' => '모든 스웜라인 칼럼의 할일 수',
    'Collapse swimlane' => '스웜라인 붕괴',
    'Expand swimlane' => '스웜라인 확장',
    'Add a new filter' => '새로운 필터 추가',
    'Share with all project members' => '모든 프로젝트 맴버 공유',
    'Shared' => '공유',
    'Owner' => '소유자',
    'Unread notifications' => '읽지않은 알림',
    'Notification methods:' => '알림 방법',
    'Unable to read your file' => '파일을 읽을 수 없습니다',
    '%d task(s) have been imported successfully.' => '%d 할일이 성공적으로 추가되었습니다',
    'Nothing has been imported!' => '추가가 되지 않았습니다!',
    'Import users from CSV file' => 'CSV 파일에서 사용자 가져오기',
    '%d user(s) have been imported successfully.' => '%d 사용자가 성공적으로 추가되었습니다',
    'Comma' => '콤마',
    'Semi-colon' => '세미콜론',
    'Tab' => '탭',
    'Vertical bar' => '세로줄',
    'Double Quote' => '이중 따옴표',
    'Single Quote' => '따옴표',
    '%s attached a file to the task #%d' => '%s가 할일 #%d에 파일을 추가하였습니다',
    'There is no column or swimlane activated in your project!' => '프로젝트에 활성화된 컬럼이나 스웜라인이 없습니다',
    'Append filter (instead of replacement)' => '필터 (변경 대신)추가',
    'Append/Replace' => '추가/변경',
    'Append' => '추가',
    'Replace' => '변경',
    'Import' => '가져오기',
    'Change sorting' => '정렬 변경',
    'Tasks Importation' => '할일 가져오기',
    'Delimiter' => '구분자',
    'Enclosure' => '동봉',
    'CSV File' => 'CSV 파일',
    'Instructions' => '명령',
    'Your file must use the predefined CSV format' => '파일은 미리 정의된 CVS 형식이어야 합니다',
    'Your file must be encoded in UTF-8' => '파일은 UTF-8로 인코딩되어야 합니다',
    'The first row must be the header' => '첫 줄은 헤더이어야 합니다',
    'Duplicates are not verified for you' => '사본이 허락되지 않습니다',
    'The due date must use the ISO format: YYYY-MM-DD' => '만기일은 ISO 형식이어야 합니다: YYYY-MM-DD',
    'Download CSV template' => 'CVS 탬플릿 내려받기',
    'No external integration registered.' => '설정이 되어있지 않습니다',
    'Duplicates are not imported' => '사본을 가져올 수 없습니다',
    'Usernames must be lowercase and unique' => '사용자 이름은 소문자이며 유일해야 합니다',
    'Passwords will be encrypted if present' => '비밀번호는 암호화됩니다',
    '%s attached a new file to the task %s' => '%s이 새로운 파일을 할일 %s에 추가했습니다',
    'Link type' => '링크 형식',
    'Assign automatically a category based on a link' => '링크 기반 자동 카테고리 할당',
    'BAM - Konvertible Mark' => 'BAM - 보스니아 마르카',
    'Assignee Username' => '담당자의 사용자이름',
    'Assignee Name' => '당장자 이름',
    'Groups' => '그룹',
    'Members of %s' => '%s의 맴버',
    'New group' => '새로운 그룹',
    'Group created successfully.' => '그룹이 성공적으로 생성되었습니다',
    'Unable to create your group.' => '그룹 생성 비활성화',
    'Edit group' => '그룹 편집',
    'Group updated successfully.' => '그룹이 성공적으로 수정되었습니다',
    'Unable to update your group.' => '그룹 수정 비활성화',
    'Add group member to "%s"' => '%s 그룹 맴버 추가',
    'Group member added successfully.' => '그룹 맴버가 성공적으로 추가되었습니다',
    'Unable to add group member.' => '그룹 맴버 추가 비활성화',
    'Remove user from group "%s"' => '%s 그룹 사용자 삭제',
    'User removed successfully from this group.' => '그룹 사용자가 성공적으로 삭제되었습니다',
    'Unable to remove this user from the group.' => '그룹 사용자 삭제 비활성화',
    'Remove group' => '그룹 삭제',
    'Group removed successfully.' => '그룹이 성공적으로 삭제되었습니다',
    'Unable to remove this group.' => '그룹 삭제 비활성화',
    'Project Permissions' => '프로젝트 권한',
    'Manager' => '매니저',
    'Project Manager' => '프로젝트 매니저',
    'Project Member' => '프로젝트 멤버',
    'Project Viewer' => '프로젝트 뷰어',
    'Your account is locked for %d minutes' => '%d분 동안 계정이 잠깁니다',
    'Invalid captcha' => '잘못된 보안 문자',
    'The name must be unique' => '이름은 유일해야 합니다',
    'View all groups' => '모든그룹보기',
    'There is no user available.' => '가능한 사용자가 없습니다',
    'Do you really want to remove the user "%s" from the group "%s"?' => '"%s" 사용자를 "%s" 에서 삭제하시겠습니까?',
    'There is no group.' => '그룹이 없습니다',
    'Add group member' => '멤버추가',
    'Do you really want to remove this group: "%s"?' => '그룹을 삭제하시겠습니까: "%s"?',
    'There is no user in this group.' => '이 그룹에는 사용자가 없습니다',
    'Permissions' => '권한',
    'Allowed Users' => '사용자 승인',
    'No specific user has been allowed.' => '구체적으로 승인된 사용자가 없습니다',
    'Role' => '역할',
    'Enter user name...' => '사용자 이름을 입력합니다...',
    'Allowed Groups' => '승인된 그룹',
    'No group has been allowed.' => '구체적으로 승인된 그룹이 없습니다',
    'Group' => '그룹',
    'Group Name' => '그룹명',
    'Enter group name...' => '그룹명을 입력합니다...',
    'Role:' => '역할: ',
    'Project members' => '프로젝트 멤버',
    '%s mentioned you in the task #%d' => '#%d 할일에서 %s가 당신을 언급하였습니다',
    '%s mentioned you in a comment on the task #%d' => '#%d 할일에서 %s가 당신의 댓글을 언급하였습니다',
    'You were mentioned in the task #%d' => '#%d 할일에서 당신이 언급되었습니다',
    'You were mentioned in a comment on the task #%d' => '할일 #%d의 댓글에서 언급되었습니다',
    'Estimated hours: ' => '예상 시간: ',
    'Actual hours: ' => '실제 시간: ',
    'Hours Spent' => '소요 시간',
    'Hours Estimated' => '예상 시간',
    'Estimated Time' => '예상 시간',
    'Actual Time' => '실제 시간',
    'Estimated vs actual time' => '예상 vs 실제 시간',
    'RUB - Russian Ruble' => 'RUB - 러시아 루블',
    'Assign the task to the person who does the action when the column is changed' => '컬럼이 변경되면 액션하지 않는 사람에게 할일을 할당합니다',
    'Close a task in a specific column' => '상세 컬럼의 할일을 종료합니다',
    'Time-based One-time Password Algorithm' => '시간에 기반한 1회용 패스워드 알고리즘',
    'Two-Factor Provider: ' => '이중 인증: ',
    'Disable two-factor authentication' => '이중 인증 비활성화',
    'Enable two-factor authentication' => '이중 인증 활성화',
    'There is no integration registered at the moment.' => '현재 등록된 통합이 없습니다.',
    'Password Reset for Kanboard' => 'Kanboard의 비밀번호 초기화',
    'Forgot password?' => '비밀번호 찾기',
    'Enable "Forget Password"' => '"비밀번호 분실" 활성화',
    'Password Reset' => '비밀번호 초기화',
    'New password' => '새로운 비밀번호',
    'Change Password' => '비밀번호 변경',
    'To reset your password click on this link:' => '비밀번호를 초기화 하시려면 링크를 눌러주세요:',
    'Last Password Reset' => '마지막 비밀번호 초기화',
    'The password has never been reinitialized.' => '비밀번호가 초기화되지 않았습니다',
    'Creation' => '생성',
    'Expiration' => '만료',
    'Password reset history' => '비밀번호 초기화 기록',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => '컬럼 "%s"와 스웜라인 "%s"의 모든 할일이 성공적으로 종료되었습니다',
    'Do you really want to close all tasks of this column?' => '이 컬럼의 모든 할일을 종료 하시겠습니까?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '컬럼 "%s"와 스웜라인 "%s"의 할일 %d가 종료될 것입니다',
    'Close all tasks in this column and this swimlane' => '컬럼의 모든 할일 마치기',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => '프로젝트 알림 방법으로 플러그인이 등록되지 않았습니다. 각각의 알림을 프로파일에서 설정하실 수 있습니다',
    'My dashboard' => '대시보드',
    'My profile' => '프로필',
    'Project owner: ' => '프로젝트 소유자:',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => '프로젝트 구분자는 선택사항이며, 숫자와 문자만 가능합니다. 예: MYPROJECT.',
    'Project owner' => '프로젝트 소유자',
    'Personal projects do not have users and groups management.' => '비밀 프로젝트는 사용자나 관리 그룹이 소유하지 않습니다',
    'There is no project member.' => '프로젝트 맴버가 없습니다',
    'Priority' => '우선순위',
    'Task priority' => '할일의 우선순위',
    'General' => '일반적인',
    'Dates' => '날짜',
    'Default priority' => '기본 우선순위',
    'Lowest priority' => '낮은 우선순위',
    'Highest priority' => '높은 우선순위',
    'Close a task when there is no activity' => '활동이 없는 할일을 종료합니다',
    'Duration in days' => '기간',
    'Send email when there is no activity on a task' => '활동이 없는 할일을 이메일로 보냅니다',
    'Unable to fetch link information.' => '링크 정보 가져오기 비활성화',
    'Daily background job for tasks' => '할일의 일일 배경 작업 ',
    'Auto' => '자동',
    'Related' => '연관된',
    'Attachment' => '첨부',
    'Web Link' => '웹 링크',
    'External links' => '외부 링크',
    'Add external link' => '외부 링크 추가',
    'Type' => '타입',
    'Dependency' => '의존',
    'Add internal link' => '내부 링크 추가',
    'Add a new external link' => '새로운 외부 링크 추가',
    'Edit external link' => '외부 링크 수정',
    'External link' => '외부 링크',
    'Copy and paste your link here...' => '여기에 링크를 복사/붙여넣기',
    'URL' => '인터넷 주소',
    'Internal links' => '내부 링크',
    'Assign to me' => '나에게 할당',
    'Me' => '나',
    'Do not duplicate anything' => '복사할까요?',
    'Projects management' => '프로젝트 관리',
    'Users management' => '사용자 관리',
    'Groups management' => '그룹 관리',
    'Create from another project' => '다른 프로젝트 생성',
    'open' => '시작',
    'closed' => '종료',
    'Priority:' => '우선순위:',
    'Reference:' => '참고:',
    'Complexity:' => '복합:',
    'Swimlane:' => '스웜라인:',
    'Column:' => '컬럼:',
    'Position:' => '위치:',
    'Creator:' => '생성자:',
    'Time estimated:' => '예상 시간:',
    '%s hours' => '%s 시간',
    'Time spent:' => '소요 시간:',
    'Created:' => '생성:',
    'Modified:' => '수정;',
    'Completed:' => '완료:',
    'Started:' => '시작:',
    'Moved:' => '이동:',
    'Task #%d' => '할일 #%d',
    'Time format' => '시간 형식',
    'Start date: ' => '시작일: ',
    'End date: ' => '종료일: ',
    'New due date: ' => '새로운 만기일: ',
    'Start date changed: ' => '변경된 시작일: ',
    'Disable personal projects' => '비밀 프로젝트 비활성화',
    'Do you really want to remove this custom filter: "%s"?' => '정의 필터를 삭제하시겠습니까: "%s"?',
    'Remove a custom filter' => '정의 필터 삭제',
    'User activated successfully.' => '사용자가 성공적으로 활성화되었습니다',
    'Unable to enable this user.' => '이 사용자를 활성화할 수 없습니다.',
    'User disabled successfully.' => '사용자가 성공적으로 비활성화되었습니다',
    'Unable to disable this user.' => '이 사용자를 비활성화할 수 없습니다.',
    'All files have been uploaded successfully.' => '모든 파일이 성공적으로 업로드되었습니다',
    'The maximum allowed file size is %sB.' => '업로드 파일의 최대 크기는 %sB 입니다',
    'Drag and drop your files here' => '파일을 이곳으로 끌고오기',
    'choose files' => '파일 선택',
    'View profile' => '프로파일 보기',
    'Two Factor' => '이중',
    'Disable user' => '사용자 비활성화',
    'Do you really want to disable this user: "%s"?' => '사용자를 비활성화 시키겠습니까: "%s"?',
    'Enable user' => '사용자 활성화',
    'Do you really want to enable this user: "%s"?' => '사용자를 활성화 시키겠습니까: "%s"?',
    'Download' => '내려받기',
    'Uploaded: %s' => '올리기: %s',
    'Size: %s' => '크기: %s',
    'Uploaded by %s' => '%s로 올리기',
    'Filename' => '파일 이름',
    'Size' => '크기',
    'Column created successfully.' => '컬럼이 성공적으로 생성되었습니다',
    'Another column with the same name exists in the project' => '프로젝트에 동일한 이름의 컬럼이 있습니다',
    'Default filters' => '기본 필터',
    'Your board doesn\'t have any columns!' => '보드에 컬럼이 존재하지 않습니다',
    'Change column position' => '컬럼 위치 변경',
    'Switch to the project overview' => '프로젝트 개요로 변경',
    'User filters' => '사용자 필터',
    'Category filters' => '카테고리 필터',
    'Upload a file' => '파일 업로드',
    'View file' => '파일 보기',
    'Last activity' => '마지막 행동',
    'Change subtask position' => '서브 할일 위치 변경',
    'This value must be greater than %d' => '이 값은 %d보다 커야 합니다',
    'Another swimlane with the same name exists in the project' => '프로젝트에 같은 이름의 스웜라인이 존재합니다',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => '예: https://example.kanboard.org/ (절대적 URLs을 생성하는데 사용됨)',
    'Actions duplicated successfully.' => '행동이 성공적으로 복제되었습니다',
    'Unable to duplicate actions.' => '행동 복제 비활성화',
    'Add a new action' => '새로운 행동 추가',
    'Import from another project' => '다른 프로젝트에서 가져오기',
    'There is no action at the moment.' => '현재 행동이 없습니다',
    'Import actions from another project' => '다른 프로젝트에서 행동 가져오기',
    'There is no available project.' => '사용 가능한 프로젝트가 없습니다',
    'Local File' => '로컬 파일',
    'Configuration' => '구성',
    'PHP version:' => 'PHP 버전:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => '운영체제 버전:',
    'Database version:' => '데이터베이스 버전:',
    'Browser:' => '브라우저:',
    'Task view' => '할일 보기',
    'Edit task' => '할일 수정',
    'Edit description' => '설명 수정',
    'New internal link' => '새로운 내부 링크',
    'Display list of keyboard shortcuts' => '키보드 숏컷 리스트 보여주기',
    'Avatar' => '아바타',
    'Upload my avatar image' => '아바타 이미지 올리기',
    'Remove my image' => '이미지 삭제',
    'The OAuth2 state parameter is invalid' => 'OAuth2 상태값이 올바르지 않습니다',
    'User not found.' => '사용자를 찾을 수 없습니다',
    'Search in activity stream' => '활성 스트림 찾기',
    'My activities' => '나의 활동',
    'Activity until yesterday' => '어제까지의 활동',
    'Activity until today' => '오늘까지의 활동',
    'Search by creator: ' => '생성자로 검색: ',
    'Search by creation date: ' => '생성 날짜로 검색: ',
    'Search by task status: ' => '할일 상태로 검색: ',
    'Search by task title: ' => '할일 제목으로 검색: ',
    'Activity stream search' => '활동 스트림 검색',
    'Projects where "%s" is manager' => '"%s" 관리자의 프로젝트',
    'Projects where "%s" is member' => '"%s" 맴버의 프로젝트',
    'Open tasks assigned to "%s"' => '"%s"에게 할당된 할일 시작하기',
    'Closed tasks assigned to "%s"' => '"%s"에게 할당된 할일 종료하기',
    'Assign automatically a color based on a priority' => '우선순위로 색깔 자동 지정',
    'Overdue tasks for the project(s) "%s"' => '"%s" 프로젝트의 기한이 지난 할일',
    'Upload files' => '파일 올리기',
    'Installed Plugins' => '설치된 플러그인',
    'Plugin Directory' => '플러그인 폴더',
    'Plugin installed successfully.' => '플러그인이 성공적으로 설치 되었습니다.',
    'Plugin updated successfully.' => '플러그인이 성공적으로 갱신 되었습니다.',
    'Plugin removed successfully.' => '플러그인이 성공적으로 삭제 되었습니다.',
    'Subtask converted to task successfully.' => '서브 할일이 할일로 성공적으로 변경 되었습니다.',
    'Unable to convert the subtask.' => '서브 할일로 변경할 수 없습니다.',
    'Unable to extract plugin archive.' => '플러그인 아카이브를 추출할 수 없습니다.',
    'Plugin not found.' => '플러그인을 찾을 수 없습니다.',
    'You don\'t have the permission to remove this plugin.' => '이 플러그인의 삭제 권한이 없습니다.',
    'Unable to download plugin archive.' => '플러그인 아카이브를 다운로드할 수 없습니다.',
    'Unable to write temporary file for plugin.' => '플러그인의 임시 파일을 기록할 수 없습니다.',
    'Unable to open plugin archive.' => '플러그인 아카이브를 열수 없습니다.',
    'There is no file in the plugin archive.' => '플러그인 아카이브에 파일이 존재하지 않습니다.',
    'Create tasks in bulk' => '대량의 할일 만들기',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => '칸보드 인스턴스가 사용자 인터페이스에서 플러그인을 설치하도록 구성되지 않았습니다',
    'There is no plugin available.' => '사용 가능한 플러그인이 없습니다.',
    'Install' => '설치',
    'Update' => '갱신',
    'Up to date' => '날짜 갱신',
    'Not available' => '사용 불가능',
    'Remove plugin' => '플러그인 삭제',
    'Do you really want to remove this plugin: "%s"?' => '정말로 플러그인을 삭제하시겠습니까: "%s"?',
    'Uninstall' => '삭제',
    'Listing' => '목록',
    'Metadata' => '메타데이터',
    'Manage projects' => '프로젝트 관리',
    'Convert to task' => '할일로 변경하기',
    'Convert sub-task to task' => '서브 할일을 할일로 변경하기',
    'Do you really want to convert this sub-task to a task?' => '정말로 서브 할일을 할일로 변경하시겠습니까?',
    'My task title' => '나의 할일 제목',
    'Enter one task by line.' => '정확히 하나의 할일로 진입',
    'Number of failed login:' => '로그인 실패 횟수:',
    'Account locked until:' => '다음동안 계정이 잠겼습니다:',
    'Email settings' => '이메일 설정',
    'Email sender address' => '이메일 보낸이 주소',
    'Email transport' => '이메일 전송',
    'Webhook token' => 'Webhook토큰',
    'Project tags management' => '프로젝트 태그 관리',
    'Tag created successfully.' => '태그가 성공적으로 생성되었습니다.',
    'Unable to create this tag.' => '태그를 생성할 수 없습니다.',
    'Tag updated successfully.' => '태그가 성공적으로 수정되었습니다.',
    'Unable to update this tag.' => '태그를 수정할 수 없습니다.',
    'Tag removed successfully.' => '태그가 성공적으로 삭제되었습니다.',
    'Unable to remove this tag.' => '태그를 삭제할 수 없습니다.',
    'Global tags management' => '전역 태그 관리',
    'Tags' => '태그',
    'Tags management' => '태그 관리',
    'Add new tag' => '태그 추가',
    'Edit a tag' => '태그 수정',
    'Project tags' => '프로젝트 태그',
    'There is no specific tag for this project at the moment.' => '현재 이 프로젝트에는 태그가 없습니다.',
    'Tag' => '태그',
    'Remove a tag' => '태그 삭제',
    'Do you really want to remove this tag: "%s"?' => '태그를 삭제하시겠습니까: "%s"?',
    'Global tags' => '전역 태그',
    'There is no global tag at the moment.' => '현재 전역 태그가 없습니다.',
    'This field cannot be empty' => '이 필드는 비워둘 수 없습니다',
    'Close a task when there is no activity in a specific column' => '활동이 없는 컬럼의 할일 마치기',
    '%s removed a subtask for the task #%d' => '%s가 할일 #%d의 서브 할일을 삭제하였습니다',
    '%s removed a comment on the task #%d' => '%s가 할일 #%d의 댓글을 삭제하였습니다',
    'Comment removed on task #%d' => '할일 #%d의 댓글이 삭제되었습니다',
    'Subtask removed on task #%d' => '할일 #%d의 서브 할일이 삭제되었습니다',
    'Hide tasks in this column in the dashboard' => '대시보드 컬럼의 할일 숨기기',
    '%s removed a comment on the task %s' => '%s가 할일 %s의 댓글을 삭제하였습니다',
    '%s removed a subtask for the task %s' => '%s가 할일 %s의 서브 할일을 삭제하였습니다',
    'Comment removed' => '댓글이 삭제되었습니다',
    'Subtask removed' => '서브 할일이 삭제되었습니다',
    '%s set a new internal link for the task #%d' => '%s가 할일 #%d의 새로운 내부 링크를 설정하였습니다',
    '%s removed an internal link for the task #%d' => '%s가 할일 #%d의 새로운 내부 링크를 삭제하였습니다',
    'A new internal link for the task #%d has been defined' => '할일 #%d의 새로운 내부 링크가 정의되었습니다',
    'Internal link removed for the task #%d' => '할일 #%d의 새로운 내부 링크가 삭제되었습니다',
    '%s set a new internal link for the task %s' => '%s가 할일 %s의 새로운 내부 링크를 설정하였습니다',
    '%s removed an internal link for the task %s' => '%s가 할일 %s의 새로운 내부 링크를 삭제하였습니다',
    'Automatically set the due date on task creation' => '할일 생성시 마감일이 자동으로 설정되었습니다',
    'Move the task to another column when closed' => '할일을 마치면 다른 컬럼으로 이동시키기',
    'Move the task to another column when not moved during a given period' => '주어진 기간동안 이동하지 않으면 할일을 다른 컬럼으로 이동시키기',
    'Dashboard for %s' => '%s의 대시보드',
    'Tasks overview for %s' => '%s의 할일 개요',
    'Subtasks overview for %s' => '%s의 서브 할일 개요',
    'Projects overview for %s' => '%s의 프로젝트 개요',
    'Activity stream for %s' => '%s의 활동기록',
    'Assign a color when the task is moved to a specific swimlane' => '할일이 특정 스웜라인으로 옮겨질 때 색상 지정',
    'Assign a priority when the task is moved to a specific swimlane' => '할일이 특정 스웜라인으로 옮겨질 때 우선순위 지정',
    'User unlocked successfully.' => '사용자 잠금 성공',
    'Unable to unlock the user.' => '사용자 해제 성공',
    'Move a task to another swimlane' => '다른 스웜라인으로 할일 이동',
    'Creator Name' => '생성자 이름',
    'Time spent and estimated' => '소요시간과 예상시간',
    'Move position' => '이동 위치',
    'Move task to another position on the board' => '할일을 보드의 다른 위치로 이동',
    'Insert before this task' => '이 할일 이전에 삽입',
    'Insert after this task' => '이 할일 이후에 삽입',
    'Unlock this user' => '사용자 잠금',
    'Custom Project Roles' => '정의 프로젝트 규칙',
    'Add a new custom role' => '새로운 정의 규칙 추가',
    'Restrictions for the role "%s"' => '"%s" 역할의 제약',
    'Add a new project restriction' => '새로운 프로젝트 제약 추가',
    'Add a new drag and drop restriction' => '새로운 드래그 앤 드롭 제약 추가',
    'Add a new column restriction' => '새로운 칼럼 제약 추가',
    'Edit this role' => '역할 수정',
    'Remove this role' => '역할 삭제',
    'There is no restriction for this role.' => '역할에 대한 제약이 없습니다.',
    'Only moving task between those columns is permitted' => '칼럼간 이동만 허용됩니다.',
    'Close a task in a specific column when not moved during a given period' => '특정 기간동안 이동하지 않은 특정 칼럼의 할일 마치기',
    'Edit columns' => '칼럼 수정',
    'The column restriction has been created successfully.' => '칼럼 제약이 생성되었습니다.',
    'Unable to create this column restriction.' => '칼럼 제약을 생성할 수 없습니다.',
    'Column restriction removed successfully.' => '칼럼 제약이 삭제되었습니다.',
    'Unable to remove this restriction.' => '칼럼 제약을 삭제할 수 없습니다.',
    'Your custom project role has been created successfully.' => '정의 프로젝트 역할이 생성되었습니다.',
    'Unable to create custom project role.' => '정의 프로젝트 역할을 생성할 수 없습니다.',
    'Your custom project role has been updated successfully.' => '정의 프로젝트 역할이 수정되었습니다.',
    'Unable to update custom project role.' => '정의 프로젝트 역할을 수정할 수 없습니다.',
    'Custom project role removed successfully.' => '정의 프로젝트 역할이 삭제되었습니다.',
    'Unable to remove this project role.' => '정의 프로젝트 역할을 삭제할 수 없습니다.',
    'The project restriction has been created successfully.' => '프로젝트 제약이 생성되었습니다.',
    'Unable to create this project restriction.' => '프로젝트 제약을 생성할 수 없습니다.',
    'Project restriction removed successfully.' => '프로젝트 제약을 삭제하였습니다.',
    'You cannot create tasks in this column.' => '이 칼럼의 할일을 생성할 수 없습니다.',
    'Task creation is permitted for this column' => '이 칼럼의 할일 생성이 허가되었습니다.',
    'Closing or opening a task is permitted for this column' => '이 칼럼의 할일 열기 혹은 닫기가 허가되었습니다.',
    'Task creation is blocked for this column' => '이 칼럼의 할일 생성이 거부되었습니다.',
    'Closing or opening a task is blocked for this column' => '이 칼럼의 할일 열기 혹은 닫기가 거부되었습니다.',
    'Task creation is not permitted' => '할일 생성이 거부되었습니다.',
    'Closing or opening a task is not permitted' => '할일 열기 혹은 닫기가 거부되었습니다.',
    'New drag and drop restriction for the role "%s"' => '"%s" 역할의 새로운 드래그 앤 드롭 제약',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => '이 역할에 속한 사용자는 원본 및 대상 칼럼 사이에서만 할일을 이동할 수 있습니다',
    'Remove a column restriction' => '칼럼 제약 삭제',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => '칼럼 제약을 "%s" 에서 "%s"로 이동하시겠습니까?',
    'New column restriction for the role "%s"' => '"%s" 역할의 새로운 칼럼 제약',
    'Rule' => '역할',
    'Do you really want to remove this column restriction?' => '칼럼 제약을 삭제하시겠습니까?',
    'Custom roles' => '정의 역할',
    'New custom project role' => '새로운 정의 프로젝트 역할',
    'Edit custom project role' => '정의 프로젝트 역할 수정',
    'Remove a custom role' => '정의 역할 삭제',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => '"%s" 정의 역할을 삭제하시겠습니까? 이 역할에 할당 된 모든 사람들이 프로젝트 멤버가됩니다.',
    'There is no custom role for this project.' => '이 프로젝트에는 정의 역할이 없습니다.',
    'New project restriction for the role "%s"' => '"%s" 역할의 새로운 프로젝트 제약',
    'Restriction' => '제약',
    'Remove a project restriction' => '프로젝트 제약 삭제',
    'Do you really want to remove this project restriction: "%s"?' => '"%s" 프로젝트 제약을 삭제하시겠습니까?',
    'Duplicate to multiple projects' => '다수의 프로젝트 복제',
    'This field is required' => '이 필드는 필수 항목입니다.',
    'Moving a task is not permitted' => '할일 이동이 거부되었습니다.',
    'This value must be in the range %d to %d' => '값의 범위는 %d 부터 %d 까지 입니다.',
    'You are not allowed to move this task.' => '당신은 할일 이동이 거부되었습니다.',
    'API User Access' => 'API 사용자 접근',
    'Preview' => '미리 보기',
    'Write' => '쓰기',
    'Write your text in Markdown' => '마크다운으로 텍스트 작성',
    'No personal API access token registered.' => '개인 API 접근 토큰이 등록되지 않았습니다.',
    'Your personal API access token is "%s"' => '개인 API 접근 토큰은 "%s"입니다.',
    'Remove your token' => '토큰 제거',
    'Generate a new token' => '새 토큰 생성',
    'Showing %d-%d of %d' => '%d-%d/%d 표시',
    'Outgoing Emails' => '발신 이메일',
    'Add or change currency rate' => '환율 추가 또는 변경',
    'Reference currency: %s' => '기준 통화: %s',
    'Add custom filters' => '사용자 정의 필터 추가',
    'Export' => '내보내기',
    'Add link label' => '링크 레이블 추가',
    'Incompatible Plugins' => '호환되지 않는 플러그인',
    'Compatibility' => '호환성',
    'Permissions and ownership' => '권한 및 소유권',
    'Priorities' => '우선 순위',
    'Close this window' => '이 창 닫기',
    'Unable to upload this file.' => '이 파일을 업로드할 수 없습니다.',
    'Import tasks' => '작업 가져오기',
    'Choose a project' => '프로젝트 선택',
    'Profile' => '프로필',
    'Application role' => '애플리케이션 역할',
    '%d invitations were sent.' => '초대 %d건이 발송되었습니다.',
    '%d invitation was sent.' => '초대 %d건이 발송되었습니다.',
    'Unable to create this user.' => '이 사용자를 생성할 수 없습니다.',
    'Kanboard Invitation' => 'Kanboard 초대',
    'Visible on dashboard' => '대시보드에 표시',
    'Created at:' => '생성 시간:',
    'Updated at:' => '업데이트 시간:',
    'There is no custom filter.' => '사용자 정의 필터가 없습니다.',
    'New User' => '새 사용자',
    'Authentication' => '인증',
    'If checked, this user will use a third-party system for authentication.' => '선택하면 이 사용자는 타사 시스템을 사용하여 인증됩니다.',
    'The password is necessary only for local users.' => '비밀번호는 로컬 사용자에게만 필요합니다.',
    'You have been invited to register on Kanboard.' => 'Kanboard에 등록하도록 초대되었습니다.',
    'Click here to join your team' => '팀에 참가하려면 여기를 클릭하세요',
    'Invite people' => '사람 초대',
    'Emails' => '이메일',
    'Enter one email address by line.' => '한 줄에 하나의 이메일 주소를 입력하세요.',
    'Add these people to this project' => '이 사람들을 이 프로젝트에 추가',
    'Add this person to this project' => '이 사람을 이 프로젝트에 추가',
    'Sign-up' => '가입',
    'Credentials' => '자격 증명',
    'New user' => '새 사용자',
    'This username is already taken' => '이 사용자 이름은 이미 사용 중입니다.',
    'Your profile must have a valid email address.' => '프로필에 유효한 이메일 주소가 있어야 합니다.',
    'TRL - Turkish Lira' => 'TRL - 터키 리라',
    'The project email is optional and could be used by several plugins.' => '프로젝트 이메일은 선택 사항이며 여러 플러그인에서 사용할 수 있습니다.',
    'The project email must be unique across all projects' => '프로젝트 이메일은 모든 프로젝트에서 고유해야 합니다.',
    'The email configuration has been disabled by the administrator.' => '이메일 설정은 관리자에 의해 비활성화되었습니다.',
    'Close this project' => '이 프로젝트 닫기',
    'Open this project' => '이 프로젝트 열기',
    'Close a project' => '프로젝트 닫기',
    'Do you really want to close this project: "%s"?' => '이 프로젝트를 정말로 닫으시겠습니까: "%s"?',
    'Reopen a project' => '프로젝트 다시 열기',
    'Do you really want to reopen this project: "%s"?' => '이 프로젝트를 정말로 다시 여시겠습니까: "%s"?',
    'This project is open' => '이 프로젝트는 열려 있습니다.',
    'This project is closed' => '이 프로젝트는 닫혀 있습니다.',
    'Unable to upload files, check the permissions of your data folder.' => '파일을 업로드할 수 없습니다. 데이터 폴더의 권한을 확인하십시오.',
    'Another category with the same name exists in this project' => '이 프로젝트에 같은 이름의 다른 카테고리가 있습니다.',
    'Comment sent by email successfully.' => '이메일로 댓글을 성공적으로 보냈습니다.',
    'Sent by email to "%s" (%s)' => '"%s" (%s)에게 이메일로 보냄',
    'Unable to read uploaded file.' => '업로드된 파일을 읽을 수 없습니다.',
    'Database uploaded successfully.' => '데이터베이스가 성공적으로 업로드되었습니다.',
    'Task sent by email successfully.' => '작업이 이메일로 성공적으로 발송되었습니다.',
    'There is no category in this project.' => '이 프로젝트에는 카테고리가 없습니다.',
    'Send by email' => '이메일로 보내기',
    'Create and send a comment by email' => '이메일로 댓글 작성 및 보내기',
    'Subject' => '제목',
    'Upload the database' => '데이터베이스 업로드',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => '이전에 다운로드한 Sqlite 데이터베이스(Gzip 형식)를 업로드할 수 있습니다.',
    'Database file' => '데이터베이스 파일',
    'Upload' => '업로드',
    'Your project must have at least one active swimlane.' => '프로젝트에는 하나 이상의 활성 스윔레인이 있어야 합니다.',
    'Project: %s' => '프로젝트: %s',
    'Automatic action not found: "%s"' => '자동 액션을 찾을 수 없습니다: "%s"',
    '%d projects' => '프로젝트 %d개',
    '%d project' => '프로젝트 %d개',
    'There is no project.' => '프로젝트가 없습니다.',
    'Sort' => '정렬',
    'Project ID' => '프로젝트 ID',
    'Project name' => '프로젝트 이름',
    'Public' => '공개',
    'Personal' => '개인',
    '%d tasks' => '작업 %d개',
    '%d task' => '작업 %d개',
    'Task ID' => '작업 ID',
    'Assign automatically a color when due date is expired' => '마감일이 지났을 때 자동으로 색상 할당',
    'Total score in this column across all swimlanes' => '모든 스윔레인에서 이 열의 총 점수',
    'HRK - Kuna' => 'HRK - 쿠나',
    'ARS - Argentine Peso' => 'ARS - 아르헨티나 페소',
    'COP - Colombian Peso' => 'COP - 콜롬비아 페소',
    '%d groups' => '그룹 %d개',
    '%d group' => '그룹 %d개',
    'Group ID' => '그룹 ID',
    'External ID' => '외부 ID',
    '%d users' => '사용자 %d명',
    '%d user' => '사용자 %d명',
    'Hide subtasks' => '하위 작업 숨기기',
    'Show subtasks' => '하위 작업 표시',
    'Authentication Parameters' => '인증 매개변수',
    'API Access' => 'API 접근',
    'No users found.' => '사용자를 찾을 수 없습니다.',
    'User ID' => '사용자 ID',
    'Notifications are activated' => '알림이 활성화되었습니다.',
    'Notifications are disabled' => '알림이 비활성화되었습니다.',
    'User disabled' => '사용자 비활성화됨',
    '%d notifications' => '알림 %d개',
    '%d notification' => '알림 %d개',
    'There is no external integration installed.' => '설치된 외부 통합이 없습니다.',
    'You are not allowed to update tasks assigned to someone else.' => '다른 사람에게 할당된 작업을 업데이트할 수 없습니다.',
    'You are not allowed to change the assignee.' => '담당자를 변경할 수 없습니다.',
    'Task suppression is not permitted' => '작업 삭제는 허용되지 않습니다.',
    'Changing assignee is not permitted' => '담당자 변경은 허용되지 않습니다.',
    'Update only assigned tasks is permitted' => '할당된 작업만 업데이트할 수 있습니다.',
    'Only for tasks assigned to the current user' => '현재 사용자에게 할당된 작업에만 해당',
    'My projects' => '내 프로젝트',
    'You are not a member of any project.' => '어떤 프로젝트의 멤버도 아닙니다.',
    'My subtasks' => '내 하위 작업',
    '%d subtasks' => '하위 작업 %d개',
    '%d subtask' => '하위 작업 %d개',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => '현재 사용자에게 할당된 작업의 경우 해당 열 간에만 작업 이동이 허용됩니다.',
    '[DUPLICATE]' => '[복제]',
    'DKK - Danish Krona' => 'DKK - 덴마크 크로네',
    'Remove user from group' => '그룹에서 사용자 제거',
    'Assign the task to its creator' => '작업을 생성자에게 할당',
    'This task was sent by email to "%s" with subject "%s".' => '이 작업은 "%s"에게 제목 "%s"으로 이메일이 발송되었습니다.',
    'Predefined Email Subjects' => '사전 정의된 이메일 제목',
    'Write one subject by line.' => '한 줄에 하나의 제목을 작성하세요.',
    'Create another link' => '다른 링크 생성',
    'BRL - Brazilian Real' => 'BRL - 브라질 헤알',
    'Add a new Kanboard task' => '새 Kanboard 작업 추가',
    'Subtask not started' => '하위 작업 시작 안 함',
    'Subtask currently in progress' => '하위 작업 현재 진행 중',
    'Subtask completed' => '하위 작업 완료됨',
    'Subtask added successfully.' => '하위 작업이 성공적으로 추가되었습니다.',
    '%d subtasks added successfully.' => '하위 작업 %d개가 성공적으로 추가되었습니다.',
    'Enter one subtask by line.' => '한 줄에 하나의 하위 작업을 입력하세요.',
    'Predefined Contents' => '사전 정의된 내용',
    'Predefined contents' => '사전 정의된 내용',
    'Predefined Task Description' => '사전 정의된 작업 설명',
    'Do you really want to remove this template? "%s"' => '정말로 이 템플릿을 제거하시겠습니까? "%s"',
    'Add predefined task description' => '사전 정의된 작업 설명 추가',
    'Predefined Task Descriptions' => '사전 정의된 작업 설명',
    'Template created successfully.' => '템플릿이 성공적으로 생성되었습니다.',
    'Unable to create this template.' => '이 템플릿을 생성할 수 없습니다.',
    'Template updated successfully.' => '템플릿이 성공적으로 업데이트되었습니다.',
    'Unable to update this template.' => '이 템플릿을 업데이트할 수 없습니다.',
    'Template removed successfully.' => '템플릿이 성공적으로 제거되었습니다.',
    'Unable to remove this template.' => '이 템플릿을 제거할 수 없습니다.',
    'Template for the task description' => '작업 설명 템플릿',
    'The start date is greater than the end date' => '시작 날짜가 종료 날짜보다 큽니다.',
    'Tags must be separated by a comma' => '태그는 쉼표로 구분해야 합니다.',
    'Only the task title is required' => '작업 제목만 필수입니다.',
    'Creator Username' => '생성자 사용자 이름',
    'Color Name' => '색상 이름',
    'Column Name' => '열 이름',
    'Swimlane Name' => '스윔레인 이름',
    'Time Estimated' => '예상 시간',
    'Time Spent' => '소요 시간',
    'External Link' => '외부 링크',
    'This feature enables the iCal feed, RSS feed and the public board view.' => '이 기능은 iCal 피드, RSS 피드 및 공개 보드 보기를 활성화합니다.',
    'Stop the timer of all subtasks when moving a task to another column' => '작업을 다른 열로 이동할 때 모든 하위 작업의 타이머 중지',
    'Subtask Title' => '하위 작업 제목',
    'Add a subtask and activate the timer when moving a task to another column' => '하위 작업을 추가하고 작업이 다른 열로 이동할 때 타이머 활성화',
    'days' => '일',
    'minutes' => '분',
    'seconds' => '초',
    'Assign automatically a color when preset start date is reached' => '사전 설정된 시작 날짜에 도달하면 자동으로 색상 할당',
    'Move the task to another column once a predefined start date is reached' => '사전 정의된 시작 날짜에 도달하면 작업을 다른 열로 이동',
    'This task is now linked to the task %s with the relation "%s"' => '이 작업은 이제 "%s" 관계를 사용하여 작업 %s에 연결되었습니다.',
    'The link with the relation "%s" to the task %s has been removed' => '작업 %s에 대한 "%s" 관계의 링크가 제거되었습니다.',
    'Custom Filter:' => '사용자 정의 필터:',
    'Unable to find this group.' => '이 그룹을 찾을 수 없습니다.',
    '%s moved the task #%d to the column "%s"' => '%s이(가) 작업 #%d을(를) "%s" 열(로)로 이동했습니다.',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s이(가) 작업 #%d을(를) "%s" 열의 %d 위치(으)로 이동했습니다.',
    '%s moved the task #%d to the swimlane "%s"' => '%s이(가) 작업 #%d을(를) "%s" 스윔레인(으)로 이동했습니다.',
    '%sh spent' => '%sh 소요',
    '%sh estimated' => '%sh 예상',
    'Select All' => '모두 선택',
    'Unselect All' => '모두 선택 해제',
    'Apply action' => '작업 적용',
    'Move selected tasks to another column or swimlane' => '선택한 작업을 다른 열 또는 스윔레인으로 이동',
    'Edit tasks in bulk' => '작업 일괄 편집',
    'Choose the properties that you would like to change for the selected tasks.' => '선택한 작업에 대해 변경하려는 속성을 선택하십시오.',
    'Configure this project' => '이 프로젝트 구성',
    'Start now' => '지금 시작',
    '%s removed a file from the task #%d' => '%s이(가) 작업 #%d에서 파일을 제거했습니다.',
    'Attachment removed from task #%d: %s' => '작업 #%d에서 첨부 파일 제거됨: %s',
    'No color' => '색상 없음',
    'Attachment removed "%s"' => '첨부 파일 "%s" 제거됨',
    '%s removed a file from the task %s' => '%s이(가) 작업 %s에서 파일을 제거했습니다.',
    'Move the task to another swimlane when assigned to a user' => '사용자에게 할당될 때 작업을 다른 스윔레인으로 이동',
    'Destination swimlane' => '대상 스윔레인',
    'Assign a category when the task is moved to a specific swimlane' => '작업이 특정 스윔레인으로 이동될 때 카테고리 할당',
    'Move the task to another swimlane when the category is changed' => '카테고리가 변경될 때 작업을 다른 스윔레인으로 이동',
    'Reorder this column by priority (ASC)' => '이 열을 우선순위로 재정렬 (오름차순)',
    'Reorder this column by priority (DESC)' => '이 열을 우선순위로 재정렬 (내림차순)',
    'Reorder this column by assignee and priority (ASC)' => '이 열을 담당자 및 우선순위로 재정렬 (오름차순)',
    'Reorder this column by assignee and priority (DESC)' => '이 열을 담당자 및 우선순위로 재정렬 (내림차순)',
    'Reorder this column by assignee (A-Z)' => '이 열을 담당자 (A-Z)로 재정렬',
    'Reorder this column by assignee (Z-A)' => '이 열을 담당자 (Z-A)로 재정렬',
    'Reorder this column by due date (ASC)' => '이 열을 마감일로 재정렬 (오름차순)',
    'Reorder this column by due date (DESC)' => '이 열을 마감일로 재정렬 (내림차순)',
    'Reorder this column by id (ASC)' => '이 열을 ID로 재정렬 (오름차순)',
    'Reorder this column by id (DESC)' => '이 열을 ID로 재정렬 (내림차순)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s이(가) 작업 #%d "%s"을(를) 프로젝트 "%s"(으)로 이동했습니다.',
    'Task #%d "%s" has been moved to the project "%s"' => '작업 #%d "%s"이(가) 프로젝트 "%s"(으)로 이동되었습니다.',
    'Move the task to another column when the due date is less than a certain number of days' => '마감일이 특정 일수 미만일 때 작업을 다른 열로 이동',
    'Automatically update the start date when the task is moved away from a specific column' => '작업이 특정 열에서 이동될 때 시작 날짜 자동 업데이트',
    'HTTP Client:' => 'HTTP 클라이언트:',
    'Assigned' => '할당됨',
    'Task limits apply to each swimlane individually' => '작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
    'Column task limits apply to each swimlane individually' => '열 작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
    'Column task limits are applied to each swimlane individually' => '열 작업 제한은 각 스윔레인에 개별적으로 적용됩니다.',
    'Column task limits are applied across swimlanes' => '열 작업 제한은 스윔레인 전반에 적용됩니다.',
    'Task limit: ' => '작업 제한:',
    'Change to global tag' => '글로벌 태그로 변경',
    'Do you really want to make the tag "%s" global?' => '정말로 태그 "%s"를 글로벌로 만드시겠습니까?',
    'Enable global tags for this project' => '이 프로젝트에 대해 글로벌 태그 활성화',
    'Group membership(s):' => '그룹 구성원:',
    '%s is a member of the following group(s): %s' => '%s은(는) 다음 그룹의 구성원입니다: %s',
    '%d/%d group(s) shown' => '그룹 %d/%d 표시됨',
    'Subtask creation or modification' => '하위 작업 생성 또는 수정',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => '작업이 특정 스윔레인으로 이동될 때 특정 사용자에게 작업 할당',
    'Comment' => '댓글',
    'Collapse vertically' => '세로로 접기',
    'Expand vertically' => '세로로 확장',
    'MXN - Mexican Peso' => 'MXN - 멕시코 페소',
    'Estimated vs actual time per column' => '열당 예상 시간 대 실제 시간',
    'HUF - Hungarian Forint' => 'HUF - 헝가리 포린트',
    'XBT - Bitcoin' => 'XBT - 비트코인',
    'You must select a file to upload as your avatar!' => '아바타로 업로드할 파일을 선택해야 합니다!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => '업로드한 파일은 유효한 이미지가 아닙니다! (*.gif, *.jpg, *.jpeg 및 *.png만 허용됩니다!)',
    'Automatically set the due date when the task is moved away from a specific column' => '작업이 특정 열에서 이동될 때 마감일 자동 설정',
    'No other projects found.' => '다른 프로젝트를 찾을 수 없습니다.',
    'Tasks copied successfully.' => '작업이 성공적으로 복사되었습니다.',
    'Unable to copy tasks.' => '작업을 복사할 수 없습니다.',
    'Theme' => '테마',
    'Theme:' => '테마:',
    'Light theme' => '밝은 테마',
    'Dark theme' => '어두운 테마',
    'Automatic theme - Sync with system' => '자동 테마 - 시스템과 동기화',
    'Application managers or more' => '애플리케이션 관리자 이상',
    'Administrators' => '관리자',
    'Visibility:' => '가시성:',
    'Standard users' => '표준 사용자',
    'Visibility is required' => '가시성은 필수입니다.',
    'The visibility should be an app role' => '가시성은 앱 역할이어야 합니다.',
    'Reply' => '답글',
    '%s wrote: ' => '%s 작성: ',
    'Number of visible tasks in this column and swimlane' => '이 열과 스윔레인에 표시되는 작업 수',
    'Number of tasks in this swimlane' => '이 스윔레인의 작업 수',
    'Unable to find another subtask in progress, you can close this window.' => '다른 진행 중인 하위 작업을 찾을 수 없습니다. 이 창을 닫을 수 있습니다.',
    'This theme is invalid' => '이 테마는 유효하지 않습니다.',
    'This role is invalid' => '이 역할은 유효하지 않습니다.',
    'This timezone is invalid' => '이 시간대는 유효하지 않습니다.',
    'This language is invalid' => '이 언어는 유효하지 않습니다.',
    'This URL is invalid' => '이 URL은 유효하지 않습니다.',
    'Date format invalid' => '잘못된 날짜 형식',
    'Time format invalid' => '잘못된 시간 형식',
    'Invalid Mail transport' => '잘못된 메일 전송',
    'Color invalid' => '잘못된 색상',
    'This value must be greater or equal to %d' => '이 값은 %d보다 크거나 같아야 합니다.',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => '파일 시작 부분에 BOM 추가 (Microsoft Excel에 필요)',
    'Just add these tag(s)' => '이 태그(들)만 추가',
    'Remove internal link(s)' => '내부 링크 제거',
    'Import tasks from another project' => '다른 프로젝트에서 작업 가져오기',
    'Select the project to copy tasks from' => '작업을 복사할 프로젝트 선택',
    'The total maximum allowed attachments size is %sB.' => '허용되는 총 첨부 파일 최대 크기는 %sB입니다.',
    'Add attachments' => '첨부 파일 추가',
    'Task #%d "%s" is overdue' => '할일 #%d "%s"의 기한이 지났습니다',
    'Enable notifications by default for all new users' => '모든 신규 사용자에 대해 기본적으로 알림 활성화',
    'Assign the task to its creator for specific columns if no assignee is set manually' => '담당자가 수동으로 지정되지 않은 경우, 지정한 컬럼에서는 작업을 생성자에게 할당',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => '사용자가 할당되지 않은 경우, 컬럼 변경으로 지정된 컬럼으로 이동할 때 작업을 로그인한 사용자에게 할당',
];
